Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(171)

Unified Diff: pkg/analyzer/lib/src/error/codes.dart

Issue 2735193002: Issue 25733. Built-in itentifiers are not permitted as prefixes. (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analyzer/lib/error/error.dart ('k') | pkg/analyzer/lib/src/generated/error_verifier.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/src/error/codes.dart
diff --git a/pkg/analyzer/lib/src/error/codes.dart b/pkg/analyzer/lib/src/error/codes.dart
index 8171fa6ab13f4c118a0c4237092fad9db00b2bec..c31595032fe21701f0059936c4acf2435bd9d111 100644
--- a/pkg/analyzer/lib/src/error/codes.dart
+++ b/pkg/analyzer/lib/src/error/codes.dart
@@ -249,6 +249,20 @@ class CompileTimeErrorCode extends ErrorCode {
"Try marking the function body with either 'async' or 'async*'.");
/**
+ * 16.33 Identifier Reference: It is a compile-time error if a built-in
+ * identifier is used as the declared name of a prefix, class, type parameter
+ * or type alias.
+ *
+ * Parameters:
+ * 0: the built-in identifier that is being used
+ */
+ static const CompileTimeErrorCode BUILT_IN_IDENTIFIER_AS_PREFIX_NAME =
+ const CompileTimeErrorCode(
+ 'BUILT_IN_IDENTIFIER_AS_PREFIX_NAME',
+ "The built-in identifier '{0}' can't be used as a prefix name.",
+ "Try choosing a different name for the prefix.");
+
+ /**
* 12.30 Identifier Reference: It is a compile-time error to use a built-in
* identifier other than dynamic as a type annotation.
*
@@ -262,9 +276,9 @@ class CompileTimeErrorCode extends ErrorCode {
"Try correcting the name to match an existing type.");
/**
* 12.30 Identifier Reference: It is a compile-time error if a built-in
* identifier is used as the declared name of a class, type parameter or type
* alias.
*
* Parameters:
* 0: the built-in identifier that is being used
@@ -276,9 +290,9 @@ class CompileTimeErrorCode extends ErrorCode {
"Try choosing a different name for the type.");
/**
* 12.30 Identifier Reference: It is a compile-time error if a built-in
* identifier is used as the declared name of a class, type parameter or type
* alias.
*
* Parameters:
* 0: the built-in identifier that is being used
@@ -290,9 +304,9 @@ class CompileTimeErrorCode extends ErrorCode {
"Try choosing a different name for the typedef.");
/**
* 12.30 Identifier Reference: It is a compile-time error if a built-in
* identifier is used as the declared name of a class, type parameter or type
* alias.
*
* Parameters:
* 0: the built-in identifier that is being used
@@ -262,9 +276,9 @@ class CompileTimeErrorCode extends ErrorCode {
"Try correcting the name to match an existing type.");
/**
- * 12.30 Identifier Reference: It is a compile-time error if a built-in
- * identifier is used as the declared name of a class, type parameter or type
- * alias.
+ * 16.33 Identifier Reference: It is a compile-time error if a built-in
+ * identifier is used as the declared name of a prefix, class, type parameter
+ * or type alias.
*
* Parameters:
@@ -276,9 +290,9 @@ class CompileTimeErrorCode extends ErrorCode {
"Try choosing a different name for the type.");
/**
- * 12.30 Identifier Reference: It is a compile-time error if a built-in
- * identifier is used as the declared name of a class, type parameter or type
- * alias.
+ * 16.33 Identifier Reference: It is a compile-time error if a built-in
+ * identifier is used as the declared name of a prefix, class, type parameter
+ * or type alias.
*
* Parameters:
@@ -290,9 +304,9 @@ class CompileTimeErrorCode extends ErrorCode {
"Try choosing a different name for the typedef.");
/**
- * 12.30 Identifier Reference: It is a compile-time error if a built-in
- * identifier is used as the declared name of a class, type parameter or type
- * alias.
+ * 16.33 Identifier Reference: It is a compile-time error if a built-in
+ * identifier is used as the declared name of a prefix, class, type parameter
+ * or type alias.
*
* Parameters:
« no previous file with comments | « pkg/analyzer/lib/error/error.dart ('k') | pkg/analyzer/lib/src/generated/error_verifier.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698